[![License](https://img.shields.io/pypi/l/dlc-generic-analysis.svg?color=green)](https://github.com/SurgicalPhotonics/dlc-generic-analysis/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/dlc-generic-analysis.svg?color=green)](https://pypi.org/project/dlc-generic-analysis)
[![codecov](https://codecov.io/gh/SurgicalPhotonics/dlc-generic-analysis/branch/main/graph/badge.svg?token=VVV5ZKD8OL)](https://codecov.io/gh/SurgicalPhotonics/dlc-generic-analysis)
[![Code Style Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![tests](https://github.com/SurgicalPhotonics/dlc-generic-analysis/actions/workflows/test.yml/badge.svg)](https://github.com/SurgicalPhotonics/dlc-generic-analysis/actions/workflows/test.yml)


# dlc-generic-analysis

A framework for creating analysis applications for [DeepLabCut](https://github.com/deeplabcut/deeplabcut) with a gui build in Qt.


# installation
`pip install "dlc-generic-analysis[gui]"` or for no GUI `pip install dlc-generic-analysis`

# Usage

For creating a basic GUI application go to [Getting Started](docs/getting_started.md)

# More information

This project was designed to be a framework for easily developing video analysis applications that depend on DeepLabCut.
For more information about DeepLabCut check out their [Github](https://github.com/deeplabcut/deeplabcut) or their 
[website](http://deeplabcut.org).
